Documentation
=============

This is the documentation for the functions of riroriro. Tutorials for the usage of these functions can be found at https://github.com/wvanzeist/riroriro_tutorials

.. toctree::
  :maxdepth: 2
  :caption: Contents:

  riroriro/index.rst
  riroriro/inspiralfuns.rst
  riroriro/mergerfirstfuns.rst
  riroriro/matchingfuns.rst
  riroriro/mergersecondfuns.rst
  riroriro/gwexporter.rst
  riroriro/snrcalculatorfuns.rst
  riroriro/horizondistfuns.rst
  riroriro/detectabilityfuns.rst
  riroriro/tests.rst
